==> aroundme_0_7_4.zip: aroundme_0_7_4/aroundme/components/core/template/barnraiser_01/structure.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_policy'];?><br />
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_policy'];?><br />
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_team'];?><br />
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (!empty($roles)) {
				?>
				
				<?php
				foreach($roles as $key => $r):
				?>
				
				<p>
					<b><?php echo $lang['role'][$r['role_id']];?></b><br />
				</p>
				<?php
				if (!empty($r['identities'])) {
				foreach($r['identities'] as $keyid => $i):
					$id_card = $i;
					include($template_path_core . "inc/identity.inc.php");
				endforeach;
				}
				endforeach;
				}
				?>
			</div>
		</div>
	</div>
</div>

==> aroundme_0_7_6.zip: aroundme_0_7_6/aroundme/components/core/template/barnraiser_01/structure.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_policy'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_policy'];?><br />
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_team'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (!empty($roles)) {
				?>
				
				<?php
				foreach($roles as $key => $r):
				?>
				
				<p>
					<b><?php echo $lang['role'][$r['role_id']];?></b><br />
				</p>
				<?php
				if (!empty($r['identities'])) {
				foreach($r['identities'] as $keyid => $i):
					$id_card = $i;
					include($template_path_core . "inc/identity.inc.php");
				endforeach;
				}
				endforeach;
				}
				?>
			</div>
		</div>
	</div>
</div>
